import json
import threading
from json import JSONDecodeError


class Data:
    lock = threading.Lock()

    def __init__(self, file_name: str):
        self.file_name = file_name
        try:
            self.data = json.load(open(file_name, 'r', encoding='utf-8'))
        except (FileNotFoundError, JSONDecodeError):
            self.data = {}
        self._privte = 15

    def __call__(self, key, from_list: list = None, loop: bool = False):
        return self.get(key, from_list, loop)

    def get(self, key, from_list: list = None, loop: bool = False):
        if key not in self.data.keys():
            self.data[key] = 0
        if isinstance(self.data[key], int):
            Data.lock.acquire()
            self.data[key] += 1
            json.dump(self.data, open(self.file_name, 'w', encoding='utf-8'), indent=2, ensure_ascii=False)
            Data.lock.release()
            try:
                return self.data[key] - 1 if from_list is None else from_list[self.data[key] - 1]
            except IndexError as IE:
                if loop:
                    self.reset(key)
                    if len(from_list) > 0:
                        return self.get(key, from_list, loop)
                    else:
                        raise IndexError("The list is empty")
                else:
                    raise IE
        else:
            return self.data[key]

    def reset(self, key):
        self.data[key] = 0
        Data.lock.acquire()
        json.dump(self.data, open(self.file_name, 'w', encoding='utf-8'), indent=2, ensure_ascii=False)
        Data.lock.release()



from automation_utilities.Mediafire import Folder


def allowed_users(folder: Folder = None, folder_id: str = None):
    for file in (folder if folder else Folder(folder_id)).files:
        if file.name == 'users.txt':
            file_content = file.text()
            return [line.split(':')[1].strip() for line in file_content.strip().split('\n')]
    return []



import requests


def __init__():
    global response
    url = "https://www.mediafire.com/api/1.4/folder/get_content.php"
    params = {
        "r": "nnpu",
        "content_type": "files",
        "filter": "all",
        "order_by": "name",
        "order_direction": "asc",
        "chunk": 1,
        "version": 1.5,
        "folder_key": "hcy8vshstj1mp",
        "response_format": "json"
    }
    response = requests.get(url, params=params).json()


__init__()

print("Response status code:", response.status_code)
print("Response content:")
print(response.text)



from uuid import getnode
from art import text2art
from colorama import Fore


def intro(name: str):
    user_id = getnode()
    print(f'{Fore.LIGHTYELLOW_EX}{text2art("Hazem3010", "banner3")}')
    indent = '\t'*5
    print(f'{Fore.GREEN}{indent}{name}\t{Fore.LIGHTMAGENTA_EX}::\t{Fore.CYAN}Your ID: {user_id}{Fore.RESET}')
    print('=' * 100)
    return str(user_id)



class Proxy:
    def __init__(
            self, text: str
    ):
        self.text = text
        try:
            self.authintication_information, self.server = text.split('@')
        except ValueError:
            self.username = self.password = None
            self.server = text

    def for_requests(self):
        server = f'http://{self.text}'
        return {"http": server, 'https': server}

    def for_playwright(self):
        try:
            username, password = self.authintication_information.split(':')
            return {
                'server': f'http://{self.server}',
                'username': username,
                'password': password,
            }
        except AttributeError:
            return {
                'server': f'http://{self.server}'
            }



import requests


class Premiumy:
    def __init__(self, api_key: str):
        self.api_key = api_key

    def message(
            self,
            start_date: str = None,
            end_date: str = None,
            senderid: str = None,
            phone: str = None,
            page: int = 1,
            per_page: int = 15
    ):
        headers = {
            "Content-type": "application/json",
            "Api-Key": self.api_key
        }
        data = {
            "id": None,
            "jsonrpc": "2.0",
            "method": "sms.mdr_full:get_list",
            "params": {
                "filter": {
                    "start_date": start_date,
                    "end_date": end_date,
                    "senderid": senderid,
                    "phone": phone,
                },
                "page": page,
                "per_page": per_page,
            }
        }
        url = 'https://api.premiumy.net/v1.0/csv'

        response = requests.post(url=url, data=data, headers=headers)
        return response.json()


import sys

from automation_utilities.Mediafire import Folder


def update(script_name: str, current_version: str, folder: Folder):
    new_version = None
    up_to_date = True
    for child in folder.files:
        if child.name == 'version.txt':
            new_version = child.text()
            if new_version != current_version:
                up_to_date = False

    if not up_to_date:
        for child in folder.files:
            if child.name == script_name:
                print("Downloading update...")
                executable_name = sys.argv[0].split('\\')[-1].split('.')
                open(f'{script_name.split(".")[0]}_V{new_version}.{executable_name[-1]}', 'wb').write(child.content())
                return True
    return False



import requests
from bs4 import BeautifulSoup


class File:
    def __init__(self, file_id: str, normal_download_link: str):
        self.name = file_id
        self.normal_download_link = normal_download_link

    def content(self):
        soup = BeautifulSoup(requests.get(self.normal_download_link).text, 'html.parser')
        url = soup.find('a', attrs={'aria-label': "Download file"}).get('href')
        return requests.get(url).content

    def text(self):
        soup = BeautifulSoup(requests.get(self.normal_download_link).text, 'html.parser')
        url = soup.find('a', attrs={'aria-label': "Download file"}).get('href')
        return requests.get(url).text


class Folder:
    def __init__(self, folderkey):
        url = "https://www.mediafire.com/api/1.4/folder/get_content.php"
        params = {
            "r": "nnpu",
            "content_type": "files",
            "filter": "all",
            "order_by": "name",
            "order_direction": "asc",
            "chunk": 1,
            "version": 1.5,
            "folder_key": folderkey,
            "response_format": "json"
        }
        folder_content = requests.get(url, params=params).json()['response']['folder_content']
        self.files = [File(file['filename'], file['links']['normal_download']) for file in folder_content['files']]



from setuptools import setup, find_packages

setup(
    name='automation_utilities',
    version='1.5.6',
    packages=find_packages(),
    install_requires=[
        'requests~=2.31.0',
        'setuptools~=65.5.1',
        'beautifulsoup4~=4.12.2',
        'playwright~=1.40.0',
        'names~=0.3.0',
        'phonenumbers~=8.13.27',
        'colorama~=0.4.6',
        'art~=6.1',
    ]
)
